@@ -9,7 +9,7 @@ PLATFORM="$4"
 IS_ROLLING_RELEASE="$5"
 IS_RELEASE="$6"
 MINIMAL_EXCLUDE_DEPS="$7"
-DEB_RELEASE=2
+DEB_RELEASE=1
 
 ARCH=$(dpkg --print-architecture)
 
@@ -65,7 +65,8 @@ echo "::endgroup::"
 
 echo "::group:: build ${LIQ_PACKAGE}-minimal.."
 
-eval "opam remove --force -y $MINIMAL_EXCLUDE_DEPS"
+# shellcheck disable=SC2086
+opam remove -y --verbose $MINIMAL_EXCLUDE_DEPS
 
 cd /tmp/liquidsoap-full
 make clean
