@@ -39,6 +39,9 @@ echo "::endgroup::"
 
 echo "::group::Setting up specific dependencies"
 
+opam update
+opam install -y odoc.3.0.0~beta1
+
 cd /tmp/liquidsoap-full/liquidsoap
 
 ./.github/scripts/checkout-deps.sh
