@@ -1,3 +1,5 @@
+module Http = Liq_http
+
 module Filename = struct
   include Filename
 
@@ -110,18 +112,28 @@ let _ =
   Lang.add_builtin ~base:file "mkdir" ~category:`File
     ~descr:"Create a directory."
     [
+      ( "parents",
+        Lang.bool_t,
+        Some (Lang.bool false),
+        Some "Also create parent directories if they do not exist." );
       ( "perms",
         Lang.int_t,
-        Some (Lang.int 0o755),
-        Some "Default file rights if created (default is `0o755`)." );
+        Some (Lang.octal_int 0o755),
+        Some "Default file rights if created." );
       ("", Lang.string_t, None, None);
     ]
     Lang.unit_t
     (fun p ->
+      let parents = List.assoc "parents" p |> Lang.to_bool in
       let perms = List.assoc "perms" p |> Lang.to_int in
       let dir = List.assoc "" p |> Lang.to_string in
       try
-        Unix.mkdir dir perms;
+        let rec recmkdir dir =
+          if not (Sys.file_exists dir) then (
+            recmkdir (Filename.dirname dir);
+            Unix.mkdir dir perms)
+        in
+        if parents then recmkdir dir else Unix.mkdir dir perms;
         Lang.unit
       with _ -> Lang.unit)
 
@@ -161,14 +173,21 @@ let _ =
       "Return a fresh temporary filename. The temporary file is created empty, \
        with permissions 0o600 (readable and writable only by the file owner)."
     [
+      ( "directory",
+        Lang.nullable_t Lang.string_t,
+        Some Lang.null,
+        Some "Directory where to create the file." );
       ("", Lang.string_t, None, Some "File prefix");
       ("", Lang.string_t, None, Some "File suffix");
     ]
     Lang.string_t
     (fun p ->
+      let temp_dir =
+        Lang.to_valued_option Lang.to_string (List.assoc "directory" p)
+      in
       try
         Lang.string
-          (Filename.temp_file
+          (Filename.temp_file ?temp_dir
              (Lang.to_string (Lang.assoc "" 1 p))
              (Lang.to_string (Lang.assoc "" 2 p)))
       with exn ->
@@ -245,21 +264,18 @@ let _ =
       let pattern =
         pattern
         |> Option.map (fun s ->
-               Pcre.substitute ~rex:(Pcre.regexp "\\.")
-                 ~subst:(fun _ -> "\\.")
-                 s)
-        |> Option.map (fun s ->
-               Pcre.substitute ~rex:(Pcre.regexp "\\*") ~subst:(fun _ -> ".*") s)
+               String.concat "\\." (String.split_on_char '.' s))
+        |> Option.map (fun s -> String.concat ".*" (String.split_on_char '*' s))
         |> Option.map (fun s -> "^" ^ s ^ "$")
         |> Option.value ~default:""
       in
       let sorted = List.assoc "sorted" p |> Lang.to_bool in
-      let rex = Pcre.regexp pattern in
+      let rex = Re.Pcre.regexp pattern in
       let dir = Lang.to_string (List.assoc "" p) in
       let dir = Lang_string.home_unrelate dir in
       let readdir dir =
         Array.to_list (Sys.readdir dir)
-        |> List.filter (fun s -> Pcre.pmatch ~rex s)
+        |> List.filter (fun s -> Re.Pcre.pmatch ~rex s)
       in
       let files =
         if not recursive then readdir dir
@@ -383,8 +399,8 @@ let _ =
         Some "Open in non-blocking mode." );
       ( "perms",
         Lang.int_t,
-        Some (Lang.int 0o644),
-        Some "Default file rights if created. Default: `0o644`" );
+        Some (Lang.octal_int 0o644),
+        Some "Default file rights if created." );
       ("", Lang.string_t, None, None);
     ]
     Builtins_socket.Socket_value.t ~descr:"Open a file."
@@ -468,22 +484,12 @@ let file_metadata =
     Lang.metadata_t ~descr:"Read metadata from a file."
     (fun p ->
       let uri = Lang.to_string (List.assoc "" p) in
-      let exclude =
+      let excluded =
         List.map Lang.to_string (Lang.to_list (List.assoc "exclude" p))
       in
-      let extension = try Some (Utils.get_ext uri) with _ -> None in
-      let mime = Magic_mime.lookup uri in
-      let metadata = Hashtbl.create 0 in
-      Plug.iter Request.mresolvers (fun name decoder ->
-          try
-            if List.mem name exclude then failwith "excluded!";
-            let m = decoder ~metadata:(Hashtbl.create 0) ~extension ~mime uri in
-            List.iter
-              (fun (k, v) ->
-                Hashtbl.replace metadata (String.lowercase_ascii k) v)
-              m
-          with _ -> ());
-      Lang.metadata metadata)
+      Lang.metadata
+        (Request.resolve_metadata ~initial_metadata:Frame.Metadata.empty
+           ~excluded uri))
 
 let () =
   Lifecycle.on_load ~name:"metadata resolvers registration" (fun () ->
@@ -507,13 +513,15 @@ let () =
                  in
                  let mime = Magic_mime.lookup uri in
                  let m =
-                   try decoder ~metadata:(Hashtbl.create 0) ~extension ~mime uri
+                   try
+                     decoder.Request.resolver ~metadata:Frame.Metadata.empty
+                       ~extension ~mime uri
                    with _ -> []
                  in
                  let m =
                    List.map (fun (k, v) -> (String.lowercase_ascii k, v)) m
                  in
-                 Lang.metadata (Frame.metadata_of_list m)))))
+                 Lang.metadata (Frame.Metadata.from_list m)))))
 
 let _ =
   Lang.add_builtin ~base:file_metadata "native" ~category:`File
@@ -528,7 +536,7 @@ let _ =
       let file = List.assoc "" p |> Lang.to_string in
       let m = try Metadata.parse_file file with _ -> [] in
       let m = List.map (fun (k, v) -> (String.lowercase_ascii k, v)) m in
-      Lang.metadata (Frame.metadata_of_list m))
+      Lang.metadata (Frame.Metadata.from_list m))
 
 let _ =
   Lang.add_builtin ~base:file "which" ~category:`File
@@ -555,7 +563,7 @@ let _ =
         Some "Copy file hierarchies." );
       ( "force",
         Lang.bool_t,
-        Some (Lang.bool false),
+        Some (Lang.bool true),
         Some
           "If a file descriptor for a destination file cannot be obtained \
            attempt to unlink the destination file and proceed." );
@@ -593,6 +601,13 @@ let _ =
         Lang.bool_t,
         Some (Lang.bool false),
         Some "Do not prompt for confirmation if the destination path exists." );
+      ( "atomic",
+        Lang.bool_t,
+        Some (Lang.bool false),
+        Some
+          "Move the file atomically. Implies `force` and raises \
+           `error.file.cross_device` if atomic move fails because the source \
+           and destination files are not on the same partition." );
       ("", Lang.string_t, None, Some "Source");
       ("", Lang.string_t, None, Some "Destination");
     ]
@@ -602,29 +617,38 @@ let _ =
         if Lang.to_bool (List.assoc "force" p) then FileUtil.Force
         else FileUtil.Ask (fun _ -> false)
       in
+      let atomic = Lang.to_bool (List.assoc "atomic" p) in
       let src = Lang.to_string (Lang.assoc "" 1 p) in
       let dst = Lang.to_string (Lang.assoc "" 2 p) in
       let error message _ =
         Runtime_error.raise ~pos:(Lang.pos p) ~message "file"
       in
       try
-        FileUtil.mv ~force ~error src dst;
+        if atomic then Unix.rename src dst
+        else FileUtil.mv ~force ~error src dst;
         Lang.unit
-      with exn ->
-        let bt = Printexc.get_raw_backtrace () in
-        Lang.raise_as_runtime ~bt ~kind:"file" exn)
+      with
+        | Unix.Unix_error (Unix.EXDEV, _, _) ->
+            Runtime_error.raise ~pos:(Lang.pos p)
+              ~message:
+                "Rename failed! Directory for temporary files appears to be on \
+                 a different filesystem"
+              "file.cross_device"
+        | exn ->
+            let bt = Printexc.get_raw_backtrace () in
+            Lang.raise_as_runtime ~bt ~kind:"file" exn)
 
 let () =
   if not Sys.win32 then (
     let umask_m = Mutex.create () in
     let get_umask =
-      Tutils.mutexify umask_m (fun () ->
+      Mutex_utils.mutexify umask_m (fun () ->
           let umask = Unix.umask 0 in
           ignore (Unix.umask umask);
           umask)
     in
     let set_umask =
-      Tutils.mutexify umask_m (fun umask -> ignore (Unix.umask umask))
+      Mutex_utils.mutexify umask_m (fun umask -> ignore (Unix.umask umask))
     in
     let umask =
       Lang.add_builtin ~base:file "umask" ~category:`File
