@@ -1,7 +1,7 @@
 (*****************************************************************************
 
-  Liquidsoap, a programmable audio stream generator.
-  Copyright 2003-2023 Savonet team
+  Liquidsoap, a programmable stream generator.
+  Copyright 2003-2024 Savonet team
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -20,8 +20,10 @@
 
  *****************************************************************************)
 
+module Http = Liq_http
+
 module Socket_domain = struct
-  include Value.MkAbstract (struct
+  include Value.MkCustom (struct
     type content = Unix.socket_domain
 
     let name = "socket_domain"
@@ -30,7 +32,7 @@ module Socket_domain = struct
       Lang.raise_error ~pos
         ~message:"Socket domain cannot be represented as json" "json"
 
-    let descr = function
+    let to_string = function
       | Unix.PF_UNIX -> "socket.domain.unix"
       | Unix.PF_INET -> "socket.domain.inet"
       | Unix.PF_INET6 -> "socket.domain.inet6"
@@ -44,7 +46,7 @@ module Socket_domain = struct
 end
 
 module Socket_type = struct
-  include Value.MkAbstract (struct
+  include Value.MkCustom (struct
     type content = Unix.socket_type
 
     let name = "socket_type"
@@ -53,7 +55,7 @@ module Socket_type = struct
       Lang.raise_error ~pos ~message:"Socket type cannot be represented as json"
         "json"
 
-    let descr = function
+    let to_string = function
       | Unix.SOCK_STREAM -> "socket.type.stream"
       | Unix.SOCK_DGRAM -> "socket.type.dgram"
       | Unix.SOCK_RAW -> "socket.type.raw"
@@ -71,10 +73,10 @@ module Socket_type = struct
 end
 
 module Inet_addr = struct
-  let descr s =
+  let to_string s =
     Printf.sprintf "socket.internet_address(%S)" (Unix.string_of_inet_addr s)
 
-  include Value.MkAbstract (struct
+  include Value.MkCustom (struct
     type content = Unix.inet_addr
 
     let name = "internet_address"
@@ -83,7 +85,7 @@ module Inet_addr = struct
       Lang.raise_error ~pos
         ~message:"Internet address type cannot be represented as json" "json"
 
-    let descr = descr
+    let to_string = to_string
 
     let compare s s' =
       Stdlib.compare (Unix.string_of_inet_addr s) (Unix.string_of_inet_addr s')
@@ -115,7 +117,7 @@ module Inet_addr = struct
 end
 
 module Socket_addr = struct
-  include Value.MkAbstract (struct
+  include Value.MkCustom (struct
     type content = Unix.sockaddr
 
     let name = "socket_address"
@@ -124,11 +126,11 @@ module Socket_addr = struct
       Lang.raise_error ~pos
         ~message:"Socket address type cannot be represented as json" "json"
 
-    let descr = function
+    let to_string = function
       | Unix.ADDR_UNIX s -> Printf.sprintf "socket.address.unix(%S)" s
       | Unix.ADDR_INET (inet_addr, port) ->
           Printf.sprintf "socket.address.inet(%s, %i)"
-            (Inet_addr.descr inet_addr)
+            (Inet_addr.to_string inet_addr)
             port
 
     let compare = Stdlib.compare
@@ -169,7 +171,7 @@ module Socket_addr = struct
 end
 
 module Socket_value = struct
-  include Value.MkAbstract (struct
+  include Value.MkCustom (struct
     type content = Http.socket
 
     let name = "socket"
@@ -178,12 +180,12 @@ module Socket_value = struct
       Lang.raise_error ~pos ~message:"Socket cannot be represented as json"
         "json"
 
-    let descr s = Printf.sprintf "<%s socket>" s#typ
+    let to_string s = Printf.sprintf "<%s socket>" s#typ
     let compare = Stdlib.compare
   end)
 
   let meths =
-    let descr_of_mode = function `Read -> "read" | `Write -> "write" in
+    let string_of_mode = function `Read -> "read" | `Write -> "write" in
     let wait_t ~mode t =
       Lang.method_t t
         [
@@ -196,7 +198,7 @@ module Socket_value = struct
                 ]
                 Lang.unit_t ),
             "Execute the given callback when the socket is ready to "
-            ^ descr_of_mode mode ^ " some data" );
+            ^ string_of_mode mode ^ " some data" );
         ]
     in
     let wait_meth ~mode socket v =
