@@ -1,7 +1,7 @@
 (*****************************************************************************
 
-  Liquidsoap, a programmable audio stream generator.
-  Copyright 2003-2023 Savonet team
+  Liquidsoap, a programmable stream generator.
+  Copyright 2003-2024 Savonet team
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -115,6 +115,7 @@ let create_decoder input =
   {
     Decoder.seek;
     eof = (fun _ -> ());
+    close = (fun _ -> ());
     decode =
       (fun buffer ->
         let len = input.Decoder.read aacbuf 0 aacbuflen in
@@ -146,7 +147,7 @@ let aac_priority =
 
 (* Get the number of channels of audio in an AAC file. *)
 let file_type ~metadata:_ ~ctype:_ filename =
-  let fd = Unix.openfile filename [Unix.O_RDONLY; Unix.O_CLOEXEC] 0o644 in
+  let fd = Decoder.openfile filename in
   Fun.protect
     ~finally:(fun () -> Unix.close fd)
     (fun () ->
@@ -220,12 +221,12 @@ let create_decoder input =
       ended := true;
       0
   in
-  { Decoder.decode; seek; eof = (fun _ -> ()) }
+  { Decoder.decode; seek; eof = (fun _ -> ()); close = (fun _ -> ()) }
 
 (* Get the number of channels of audio in an MP4 file. *)
 let file_type ~metadata:_ ~ctype:_ filename =
   let dec = Faad.create () in
-  let fd = Unix.openfile filename [Unix.O_RDONLY; Unix.O_CLOEXEC] 0o644 in
+  let fd = Decoder.openfile filename in
   Fun.protect
     ~finally:(fun () -> Unix.close fd)
     (fun () ->
@@ -281,11 +282,21 @@ let get_tags ~metadata:_ ~extension ~mime file =
       (Decoder.test_file ~log ~extension ~mime ~mimes:(Some mp4_mime_types#get)
          ~extensions:(Some mp4_file_extensions#get) file)
   then raise Not_found;
-  let fd = Unix.openfile file [Unix.O_RDONLY; Unix.O_CLOEXEC] 0o644 in
+  let fd = Decoder.openfile file in
   Fun.protect
     ~finally:(fun () -> Unix.close fd)
     (fun () ->
       let mp4 = Faad.Mp4.openfile_fd fd in
       Array.to_list (Faad.Mp4.metadata mp4))
 
-let () = Plug.register Request.mresolvers "mp4" ~doc:"MP4 tag decoder." get_tags
+let mp4_metadata_decoder_priority =
+  Dtools.Conf.int
+    ~p:(Request.conf_metadata_decoder_priorities#plug "mp4")
+    "Priority for the mp4 metadata decoder" ~d:1
+
+let () =
+  Plug.register Request.mresolvers "mp4" ~doc:"MP4 tag decoder."
+    {
+      Request.priority = (fun () -> mp4_metadata_decoder_priority#get);
+      resolver = get_tags;
+    }
