@@ -1,7 +1,7 @@
 (*****************************************************************************
 
-  Liquidsoap, a programmable audio stream generator.
-  Copyright 2003-2023 Savonet team
+  Liquidsoap, a programmable stream generator.
+  Copyright 2003-2024 Savonet team
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -35,10 +35,10 @@ module type InternalResampler_type = sig
 
   val create :
     ?options:Swresample.options list ->
-    Avutil__Channel_layout.t ->
+    Avutil.Channel_layout.t ->
     ?in_sample_format:Avutil__Sample_format.t ->
     int ->
-    Avutil__Channel_layout.t ->
+    Avutil.Channel_layout.t ->
     ?out_sample_format:Avutil__Sample_format.t ->
     int ->
     t
@@ -81,14 +81,6 @@ let get_channel_layout ~pos channels =
           %d channels.."
          channels)
 
-let can_split stream =
-  let params = Av.get_codec_params stream in
-  match Avcodec.descriptor params with
-    | None -> fun () -> true
-    | Some { Avcodec.properties } when List.mem `Intra_only properties ->
-        fun () -> true
-    | _ -> fun () -> Av.was_keyframe stream
-
 (* This function optionally splits frames into [frame_size]
    and also adds PTS based on targeted [time_base], [sample_rate]
    and number of channel. *)
@@ -130,7 +122,7 @@ let write_audio_frame ~time_base ~sample_rate ~channel_layout ~sample_format
           add_filter_frame_pts frame;
           Avfilter.Utils.convert_audio converter write_frame (`Frame frame)
 
-let mk_audio ~pos ~mode ~codec ~params ~options ~field output =
+let mk_audio ~pos ~on_keyframe ~mode ~codec ~params ~options ~field output =
   let internal_resampler =
     match params.Ffmpeg_format.pcm_kind with
       | pcm_kind when Content_audio.is_kind pcm_kind ->
@@ -177,10 +169,9 @@ let mk_audio ~pos ~mode ~codec ~params ~options ~field output =
         src_channel_layout src_samplerate target_channel_layout
         target_samplerate
     in
-    fun frame start len ->
-      let astart = Frame.audio_of_main start in
-      let alen = Frame.audio_of_main len in
-      let content = Content.sub (Frame.get frame field) astart alen in
+    fun frame ->
+      let alen = AFrame.position frame in
+      let content = Frame.get frame field in
       let pcm = InternalResampler.Content.get_data content in
       [InternalResampler.convert ~length:alen ~offset:0 resampler pcm]
   in
@@ -202,7 +193,9 @@ let mk_audio ~pos ~mode ~codec ~params ~options ~field output =
               let f =
                 if
                   src_samplerate <> target_samplerate
-                  || src_channel_layout <> target_channel_layout
+                  || (not
+                        (Avutil.Channel_layout.compare src_channel_layout
+                           target_channel_layout))
                   || src_sample_format <> target_sample_format
                 then (
                   let fn =
@@ -218,14 +211,13 @@ let mk_audio ~pos ~mode ~codec ~params ~options ~field output =
       in
       resampler frame
     in
-    fun frame start len ->
+    fun frame ->
       let frames =
-        Ffmpeg_raw_content.Audio.(get_data (Generator.get_field frame field))
-          .Ffmpeg_content_base.data
-      in
-      let frames =
-        List.filter (fun (pos, _) -> start <= pos && pos < start + len) frames
+        Ffmpeg_raw_content.Audio.(get_data (Frame.get frame field))
+          .Content.Video.data
       in
+      let len = Frame.position frame in
+      let frames = List.filter (fun (pos, _) -> 0 <= pos && pos < len) frames in
       List.map (fun (_, { Ffmpeg_raw_content.frame }) -> resample frame) frames
   in
 
@@ -269,6 +261,21 @@ let mk_audio ~pos ~mode ~codec ~params ~options ~field output =
       (Printf.sprintf "Unrecognized options: %s"
          (Ffmpeg_format.string_of_options options));
 
+  let intra_only =
+    let params = Av.get_codec_params stream in
+    match Avcodec.descriptor params with
+      | None -> true
+      | Some { Avcodec.properties } -> List.mem `Intra_only properties
+  in
+
+  let on_keyframe =
+    Option.map
+      (fun on_keyframe () ->
+        if not intra_only then Av.flush output;
+        on_keyframe ())
+      on_keyframe
+  in
+
   let codec_attr () = Av.codec_attr stream in
 
   let bitrate () = Av.bitrate stream in
@@ -284,19 +291,17 @@ let mk_audio ~pos ~mode ~codec ~params ~options ~field output =
     try
       write_audio_frame ~time_base:(Av.get_time_base stream)
         ~sample_rate:target_samplerate ~channel_layout:target_channel_layout
-        ~sample_format:target_sample_format ~frame_size (Av.write_frame stream)
+        ~sample_format:target_sample_format ~frame_size
+        (Av.write_frame ?on_keyframe stream)
     with e ->
       log#severe "Error writing audio frame: %s." (Printexc.to_string e);
       raise e
   in
 
-  let encode frame start len =
-    List.iter write_frame (converter frame start len)
-  in
+  let encode frame = List.iter write_frame (converter frame) in
 
   {
     Ffmpeg_encoder_common.mk_stream;
-    can_split = can_split stream;
     encode;
     flush = (fun () -> ());
     codec_attr;
@@ -304,7 +309,7 @@ let mk_audio ~pos ~mode ~codec ~params ~options ~field output =
     video_size;
   }
 
-let mk_video ~pos ~mode ~codec ~params ~options ~field output =
+let mk_video ~pos ~on_keyframe ~mode ~codec ~params ~options ~field output =
   let codec =
     try Avcodec.Video.find_encoder_by_name codec
     with e ->
@@ -363,6 +368,21 @@ let mk_video ~pos ~mode ~codec ~params ~options ~field output =
       (Printf.sprintf "Unrecognized options: %s"
          (Ffmpeg_format.string_of_options options));
 
+  let intra_only =
+    let params = Av.get_codec_params stream in
+    match Avcodec.descriptor params with
+      | None -> true
+      | Some { Avcodec.properties } -> List.mem `Intra_only properties
+  in
+
+  let on_keyframe =
+    Option.map
+      (fun on_keyframe () ->
+        if not intra_only then Av.flush output;
+        on_keyframe ())
+      on_keyframe
+  in
+
   let codec_attr () = Av.codec_attr stream in
 
   let bitrate () = Av.bitrate stream in
@@ -407,7 +427,7 @@ let mk_video ~pos ~mode ~codec ~params ~options ~field output =
     in
     Avutil.Frame.set_pts frame frame_pts;
     start_pts := Int64.succ !start_pts;
-    Av.write_frame stream frame
+    Av.write_frame ?on_keyframe stream frame
   in
 
   let fps_converter ~stream_idx ~time_base frame =
@@ -440,23 +460,23 @@ let mk_video ~pos ~mode ~codec ~params ~options ~field output =
     let time_base = Ffmpeg_utils.liq_video_sample_time_base () in
     let stream_idx = 1L in
 
-    fun frame start len ->
-      let vstart = Frame.video_of_main start in
-      let vstop = Frame.video_of_main (start + len) in
-      let vbuf = VFrame.data ~field frame in
-      for i = vstart to vstop - 1 do
-        let f =
-          Video.Canvas.get vbuf i
-          (* TODO: we could scale instead of aggressively changing the viewport *)
-          |> Video.Canvas.Image.viewport src_width src_height
-          |> Video.Canvas.Image.render ~transparent:false
-        in
-        let vdata = Ffmpeg_utils.pack_image f in
-        let frame = InternalScaler.convert scaler vdata in
-        Avutil.Frame.set_pts frame (Some !nb_frames);
-        nb_frames := Int64.succ !nb_frames;
-        cb ~stream_idx ~time_base frame
-      done
+    fun frame ->
+      let content = Frame.get frame field in
+      let buf = Content.Video.get_data content in
+      List.iter
+        (fun (_, img) ->
+          let f =
+            img
+            (* TODO: we could scale instead of aggressively changing the viewport *)
+            |> Video.Canvas.Image.viewport src_width src_height
+            |> Video.Canvas.Image.render ~transparent:false
+          in
+          let vdata = Ffmpeg_utils.pack_image f in
+          let frame = InternalScaler.convert scaler vdata in
+          Avutil.Frame.set_pts frame (Some !nb_frames);
+          nb_frames := Int64.succ !nb_frames;
+          cb ~stream_idx ~time_base frame)
+        buf.Content.Video.data
   in
 
   let raw_converter cb =
@@ -489,15 +509,14 @@ let mk_video ~pos ~mode ~codec ~params ~options ~field output =
       in
       scaler frame
     in
-    fun frame start len ->
-      let stop = start + len in
+    fun frame ->
+      let len = Frame.position frame in
       let { Ffmpeg_raw_content.VideoSpecs.data } =
-        Ffmpeg_raw_content.Video.get_data (Generator.get_field frame field)
+        Ffmpeg_raw_content.Video.get_data (Frame.get frame field)
       in
       List.iter
         (fun (pos, { Ffmpeg_raw_content.time_base; frame; stream_idx }) ->
-          if start <= pos && pos < stop then
-            cb ~stream_idx ~time_base (scale frame))
+          if 0 <= pos && pos < len then cb ~stream_idx ~time_base (scale frame))
         data
   in
 
@@ -509,7 +528,6 @@ let mk_video ~pos ~mode ~codec ~params ~options ~field output =
 
   {
     Ffmpeg_encoder_common.mk_stream;
-    can_split = can_split stream;
     encode;
     flush;
     codec_attr;
