@@ -1,7 +1,7 @@
 (*****************************************************************************
 
-  Liquidsoap, a programmable audio stream generator.
-  Copyright 2003-2023 Savonet team
+  Liquidsoap, a programmable stream generator.
+  Copyright 2003-2024 Savonet team
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -92,17 +92,17 @@ let () =
          (fun version ->
            Strings.Mutable.add encoded
              (Utils.id3v2_of_metadata ~version
-                (Frame.list_of_metadata (Export_metadata.to_metadata metadata))))
+                (Frame.Metadata.to_list
+                   (Frame.Metadata.Export.to_metadata metadata))))
          mp3.id3v2);
-    let encode frame start len =
-      let b = AFrame.pcm frame in
+    let encode frame =
       Generator.put pending_data Frame.Fields.audio
-        (Content.sub (Content.Audio.lift_data b) start len);
+        (Frame.get frame Frame.Fields.audio);
       while Generator.length pending_data > frame_size do
         let pcm =
           Content.Audio.get_data
             (Frame.Fields.find Frame.Fields.audio
-               (Generator.get ~length:frame_size pending_data))
+               (Generator.slice pending_data frame_size))
         in
         Strings.Mutable.add encoded
           (if channels = 1 then
