@@ -260,6 +260,23 @@ let meth () =
                      (Lang.string (Utils.name_of_sockaddr origin))
                      (Builtins_srt.Socket_value.to_base_value s))
                  s#get_sockets)) );
+    ( "connect",
+      ([], Lang.fun_t [] Lang.unit_t),
+      "In sender mode, connect to remote server. In listener mode, setup \
+       listening socket.",
+      fun s ->
+        Lang.val_fun [] (fun _ ->
+            s#set_should_stop false;
+            s#connect;
+            Lang.unit) );
+    ( "disconnect",
+      ([], Lang.fun_t [] Lang.unit_t),
+      "Disconnect all connected socket.",
+      fun s ->
+        Lang.val_fun [] (fun _ ->
+            s#set_should_stop true;
+            s#disconnect;
+            Lang.unit) );
   ]
 
 type common_options = {
@@ -406,10 +423,9 @@ let log_handler { Srt.Log.message } =
   in
   log#f conf_level#get "%s" message
 
-(** Common polling task for all srt input/output.
-  * sockets entering a poll are always set to non-blocking
-  * and set back to blocking when exiting. They are also always
-  * removed from the poll when done. *)
+(** Common polling task for all srt input/output. sockets entering a poll are
+    always set to non-blocking and set back to blocking when exiting. They are
+    also always removed from the poll when done. *)
 module Poll = struct
   type t = {
     p : Srt.Poll.t;
@@ -529,7 +545,7 @@ class virtual base () =
     val should_stop = Atomic.make false
     val id = id ()
     method private should_stop = Atomic.get shutdown || Atomic.get should_stop
-    method private set_should_stop = Atomic.set should_stop
+    method set_should_stop = Atomic.set should_stop
     method srt_id = id
   end
 
@@ -637,7 +653,7 @@ class virtual caller ~enforced_encryption ~pbkeylen ~passphrase ~streamid
         self#log#important "Connect failed: %s" (Printexc.to_string exn);
         if not (Atomic.get task_should_stop) then polling_delay else -1.
 
-    method private connect =
+    method connect =
       Atomic.set task_should_stop false;
       match connect_task with
         | Some t -> Duppy.Async.wake_up t
@@ -732,7 +748,7 @@ class virtual listener ~enforced_encryption ~pbkeylen ~passphrase ~max_clients
               Srt.close s;
               Printexc.raise_with_backtrace exn bt)
 
-    method private connect =
+    method connect =
       let rec accept_connection s =
         try
           let client, origin = Srt.accept s in
@@ -1033,7 +1049,10 @@ let _ =
                ~on_disconnect ~messageapi ~max ~dump ~on_start ~on_stop
                ~autostart format
               :> < Start_stop.active_source
-                 ; get_sockets : (Unix.sockaddr * Srt.socket) list >)
+                 ; get_sockets : (Unix.sockaddr * Srt.socket) list
+                 ; set_should_stop : bool -> unit
+                 ; connect : unit
+                 ; disconnect : unit >)
         | `Caller ->
             (new input_caller
                ~enforced_encryption ~pbkeylen ~passphrase ~streamid
@@ -1042,7 +1061,10 @@ let _ =
                ~connection_timeout ~on_disconnect ~messageapi ~max ~dump
                ~on_start ~on_socket ~on_stop ~autostart format
               :> < Start_stop.active_source
-                 ; get_sockets : (Unix.sockaddr * Srt.socket) list >))
+                 ; get_sockets : (Unix.sockaddr * Srt.socket) list
+                 ; set_should_stop : bool -> unit
+                 ; connect : unit
+                 ; disconnect : unit >))
 
 class virtual output_base ~payload_size ~messageapi ~on_start ~on_stop
   ~infallible ~register_telnet ~autostart ~on_disconnect ~encoder_factory source
@@ -1058,14 +1080,14 @@ class virtual output_base ~payload_size ~messageapi ~on_start ~on_stop
         ~output_kind:"srt" ~on_start ~on_stop ~infallible ~register_telnet
           ~export_cover_metadata:false ~autostart ~name:"output.srt" source
 
-    val mutable encoder = None
+    val mutable encoder = Atomic.make None
 
     initializer
       let on_disconnect_cur = !on_disconnect in
       on_disconnect :=
         fun () ->
           ignore (Strings.Mutable.flush buffer);
-          encoder <- None;
+          Atomic.set encoder None;
           on_disconnect_cur ()
 
     method private send_chunk =
@@ -1089,6 +1111,7 @@ class virtual output_base ~payload_size ~messageapi ~on_start ~on_stop
         try f pos socket
         with exn ->
           let bt = Printexc.get_raw_backtrace () in
+          self#stop_encoder;
           self#client_error socket exn bt
       in
       List.iter (f 0) self#get_sockets
@@ -1102,11 +1125,11 @@ class virtual output_base ~payload_size ~messageapi ~on_start ~on_stop
     method private get_encoder =
       self#mutexify
         (fun () ->
-          match encoder with
+          match Atomic.get encoder with
             | Some enc -> enc
             | None ->
                 let enc = encoder_factory self#id Frame.Metadata.Export.empty in
-                encoder <- Some enc;
+                Atomic.set encoder (Some enc);
                 enc)
         ()
 
@@ -1120,8 +1143,24 @@ class virtual output_base ~payload_size ~messageapi ~on_start ~on_stop
 
     method private stop =
       self#mutexify (fun () -> Atomic.set should_stop true) ();
+      self#stop_encoder;
+      self#send_chunks;
       self#disconnect
 
+    method stop_encoder =
+      if self#is_connected then (
+        try
+          self#mutexify
+            (Strings.Mutable.append_strings buffer)
+            (self#get_encoder.Encoder.stop ())
+        with exn ->
+          let bt = Printexc.get_backtrace () in
+          Utils.log_exception ~log:self#log ~bt
+            (Printf.sprintf "Error while stopping encoder: %s"
+               (Printexc.to_string exn)));
+      ignore (Strings.Mutable.flush buffer);
+      Atomic.set encoder None
+
     method private encode frame =
       if self#is_connected then self#get_encoder.Encoder.encode frame
       else Strings.empty
@@ -1139,12 +1178,13 @@ class output_caller ~enforced_encryption ~pbkeylen ~passphrase ~streamid
   ~polling_delay ~payload_size ~messageapi ~on_start ~on_stop ~infallible
   ~register_telnet ~autostart ~on_socket ~on_connect ~on_disconnect
   ~prefer_address ~port ~hostname ~read_timeout ~write_timeout
-  ~connection_timeout ~encoder_factory source =
+  ~connection_timeout ~encoder_factory source_val =
+  let source = Lang.to_source source_val in
   object (self)
     inherit
       output_base
         ~payload_size ~messageapi ~on_start ~on_stop ~infallible
-          ~register_telnet ~autostart ~on_disconnect ~encoder_factory source
+          ~register_telnet ~autostart ~on_disconnect ~encoder_factory source_val
 
     inherit
       caller
@@ -1153,6 +1193,8 @@ class output_caller ~enforced_encryption ~pbkeylen ~passphrase ~streamid
           ~write_timeout ~connection_timeout ~messageapi ~on_connect
           ~on_disconnect ~on_socket
 
+    method self_sync = source#self_sync
+
     method private get_sockets =
       try [self#get_socket] with Not_connected -> []
 
@@ -1169,12 +1211,13 @@ class output_listener ~enforced_encryption ~pbkeylen ~passphrase
   ~listen_callback ~max_clients ~payload_size ~messageapi ~on_start ~on_stop
   ~infallible ~register_telnet ~autostart ~on_connect ~on_disconnect
   ~bind_address ~port ~prefer_address ~on_socket ~read_timeout ~write_timeout
-  ~encoder_factory source =
+  ~encoder_factory source_val =
+  let source = Lang.to_source source_val in
   object (self)
     inherit
       output_base
         ~payload_size ~messageapi ~on_start ~on_stop ~infallible
-          ~register_telnet ~autostart ~on_disconnect ~encoder_factory source
+          ~register_telnet ~autostart ~on_disconnect ~encoder_factory source_val
 
     inherit
       listener
@@ -1183,6 +1226,8 @@ class output_listener ~enforced_encryption ~pbkeylen ~passphrase
           ~enforced_encryption ~pbkeylen ~passphrase ~listen_callback
           ~max_clients ()
 
+    method self_sync = source#self_sync
+
     method private client_error socket exn bt =
       Utils.log_exception ~log:self#log
         ~bt:(Printexc.raw_backtrace_to_string bt)
@@ -1273,7 +1318,10 @@ let _ =
                ~connection_timeout ~infallible ~register_telnet ~messageapi
                ~encoder_factory ~on_socket ~on_connect ~on_disconnect source
               :> < Output.output
-                 ; get_sockets : (Unix.sockaddr * Srt.socket) list >)
+                 ; get_sockets : (Unix.sockaddr * Srt.socket) list
+                 ; set_should_stop : bool -> unit
+                 ; connect : unit
+                 ; disconnect : unit >)
         | `Listener ->
             (new output_listener
                ~enforced_encryption ~pbkeylen ~passphrase ~bind_address ~port
@@ -1282,4 +1330,7 @@ let _ =
                ~register_telnet ~messageapi ~encoder_factory ~on_connect
                ~on_disconnect ~listen_callback ~max_clients source
               :> < Output.output
-                 ; get_sockets : (Unix.sockaddr * Srt.socket) list >))
+                 ; get_sockets : (Unix.sockaddr * Srt.socket) list
+                 ; set_should_stop : bool -> unit
+                 ; connect : unit
+                 ; disconnect : unit >))
