@@ -44,9 +44,12 @@ module ClockValue = struct
   let methods =
     [
       ( "id",
-        Lang.fun_t [] Lang.string_t,
+        Lang.ref_t Lang.string_t,
         "The clock's id",
-        fun c -> Lang.val_fun [] (fun _ -> Lang.string (Clock.id c)) );
+        fun c ->
+          let get () = Lang.string (Clock.id c) in
+          let set v = Clock.set_id c (Lang.to_string v) in
+          Lang.reference get set );
       ( "sync",
         Lang.fun_t [] Lang.string_t,
         "The clock's current sync mode. One of: `\"stopped\"`, `\"stopping\"`, \
@@ -297,35 +300,15 @@ let source_methods =
       "Is the source currently controlling its own real-time loop.",
       fun s -> val_fun [] (fun _ -> bool (snd s#self_sync <> None)) );
     ( "log",
-      ( [],
-        record_t
-          [
-            ( "level",
-              method_t
-                (fun_t [] (nullable_t int_t))
-                [
-                  ( "set",
-                    ([], fun_t [(false, "", int_t)] unit_t),
-                    "Set the source's log level" );
-                ] );
-          ] ),
+      ([], record_t [("level", ref_t int_t)]),
       "Get or set the source's log level, from `1` to `5`.",
       fun s ->
         record
           [
             ( "level",
-              meth
-                (val_fun [] (fun _ ->
-                     match s#log#level with Some lvl -> int lvl | None -> null))
-                [
-                  ( "set",
-                    val_fun
-                      [("", "", None)]
-                      (fun p ->
-                        let lvl = min 5 (max 1 (to_int (List.assoc "" p))) in
-                        s#log#set_level lvl;
-                        unit) );
-                ] );
+              reference
+                (fun () -> int s#log#level)
+                (fun v -> s#log#set_level (to_int v)) );
           ] );
     ( "is_up",
       ([], fun_t [] bool_t),
@@ -432,7 +415,8 @@ let add_value_flag v flag =
     | Value.Float _ | Value.String _ | Value.Bool _ | Value.Null _ -> ()
     | v -> Value.add_flag v flag
 
-(** Ensure that the frame contents of all the sources occurring in the value agree with [t]. *)
+(** Ensure that the frame contents of all the sources occurring in the value
+    agree with [t]. *)
 let check_content v t =
   let check t t' = Typing.(t <: t') in
   let rec check_value v t =
@@ -539,18 +523,20 @@ let check_content v t =
   in
   check_value v t
 
-(** An operator is a builtin function that builds a source.
-  * It is registered using the wrapper [add_operator].
-  * Creating the associated function type (and function) requires some work:
-  *  - Specify which content_kind the source will carry:
-  *    a given fixed number of channels, any fixed, a variable number?
-  *  - The content_kind can also be linked to a type variable,
-  *    e.g. the parameter of a format type.
-  * From this high-level description a type is created. Often it will
-  * carry a type constraint.
-  * Once the type has been inferred, the function might be executed,
-  * and at this point the type might still not be known completely
-  * so we have to force its value within the acceptable range. *)
+(** An operator is a builtin function that builds a source. It is registered
+    using the wrapper [add_operator]. Creating the associated function type (and
+    function) requires some work:
+    - Specify which content_kind the source will carry: a given fixed number of
+      channels, any fixed, a variable number?
+    - The content_kind can also be linked to a type variable, e.g. the parameter
+      of a format type.
+
+    From this high-level description a type is created. Often it will carry a
+    type constraint.
+
+    Once the type has been inferred, the function might be executed, and at this
+    point the type might still not be known completely so we have to force its
+    value within the acceptable range. *)
 
 let _meth = meth
 
