@@ -1,7 +1,7 @@
 (*****************************************************************************
 
-  Liquidsoap, a programmable audio stream generator.
-  Copyright 2003-2023 Savonet team
+  Liquidsoap, a programmable stream generator.
+  Copyright 2003-2024 Savonet team
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -26,19 +26,19 @@ open Source
 class clip ~field (source : source) =
   object
     inherit operator ~name:"clip" [source]
-    method stype = source#stype
+    method fallible = source#fallible
     method remaining = source#remaining
     method seek_source = source#seek_source
-    method private _is_ready = source#is_ready
+    method private can_generate_frame = source#is_ready
     method abort_track = source#abort_track
     method self_sync = source#self_sync
 
-    method private get_frame buf =
-      let offset = AFrame.position buf in
-      source#get buf;
-      let b = Content.Audio.get_data (Frame.get buf field) in
-      let position = AFrame.position buf in
-      Audio.clip b offset (position - offset)
+    method private generate_frame =
+      let c = source#get_mutable_content field in
+      let b = Content.Audio.get_data c in
+      let position = source#frame_audio_position in
+      Audio.clip b 0 position;
+      source#set_frame_data field Content.Audio.lift_data b
   end
 
 let _ =
