@@ -1,7 +1,7 @@
 (*****************************************************************************
 
-  Liquidsoap, a programmable audio stream generator.
-  Copyright 2003-2023 Savonet team
+  Liquidsoap, a programmable stream generator.
+  Copyright 2003-2024 Savonet team
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -26,11 +26,11 @@ open Source
 class virtual base ~name (source : source) =
   object
     inherit operator ~name [source]
-    method stype = source#stype
+    method fallible = source#fallible
     method remaining = source#remaining
     method seek_source = source#seek_source
     method self_sync = source#self_sync
-    method private _is_ready = source#is_ready
+    method private can_generate_frame = source#is_ready
     method abort_track = source#abort_track
   end
 
@@ -38,23 +38,27 @@ class merge (source : source) out =
   object
     inherit base source ~name:"midi.merge_all"
 
-    method private get_frame buf =
-      source#get buf;
-      let m = MFrame.midi buf in
+    method private generate_frame =
+      let m =
+        Content.Midi.get_data (source#get_mutable_content Frame.Fields.midi)
+      in
       for c = 0 to Array.length m - 1 do
         MIDI.merge m.(out) m.(c);
         if c <> out then MIDI.clear_all m.(c)
-      done
+      done;
+      source#set_frame_data Frame.Fields.midi Content.Midi.lift_data m
   end
 
 class remove (source : source) t =
   object
     inherit base source ~name:"midi.remove"
 
-    method private get_frame buf =
-      source#get buf;
-      let m = MFrame.midi buf in
-      List.iter (fun c -> if c < Array.length m then MIDI.clear_all m.(c)) t
+    method private generate_frame =
+      let m =
+        Content.Midi.get_data (source#get_mutable_content Frame.Fields.midi)
+      in
+      List.iter (fun c -> if c < Array.length m then MIDI.clear_all m.(c)) t;
+      source#set_frame_data Frame.Fields.midi Content.Midi.lift_data m
   end
 
 let _ =
