@@ -1,7 +1,7 @@
 (*****************************************************************************
 
-  Liquidsoap, a programmable audio stream generator.
-  Copyright 2003-2023 Savonet team
+  Liquidsoap, a programmable stream generator.
+  Copyright 2003-2024 Savonet team
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -27,18 +27,16 @@ type mode = Encode | Decode
 class msstereo ~field (source : source) mode width =
   object
     inherit operator ~name:"stereo.ms.encode" [source]
-    method stype = source#stype
-    method private _is_ready = source#is_ready
+    method fallible = source#fallible
+    method private can_generate_frame = source#is_ready
     method remaining = source#remaining
     method seek_source = source#seek_source
     method self_sync = source#self_sync
     method abort_track = source#abort_track
 
-    method private get_frame buf =
-      let offset = AFrame.position buf in
-      source#get buf;
-      let buffer = Content.Audio.get_data (Frame.get buf field) in
-      for i = offset to AFrame.position buf - 1 do
+    method private generate_frame =
+      let buffer = Content.Audio.get_data (source#get_mutable_content field) in
+      for i = 0 to source#frame_audio_position - 1 do
         match mode with
           | Encode ->
               let left = buffer.(0).(i) and right = buffer.(1).(i) in
@@ -54,7 +52,8 @@ class msstereo ~field (source : source) mode width =
               (* left *)
               buffer.(1).(i) <- mid -. (side *. width)
         (* right *)
-      done
+      done;
+      source#set_frame_data field Content.Audio.lift_data buffer
   end
 
 let stereo_ms = Lang.add_module ~base:Stereo.stereo "ms"
@@ -89,18 +88,16 @@ let _ =
 class spatializer ~field ~width (source : source) =
   object
     inherit operator ~name:"stereo.width" [source]
-    method stype = source#stype
-    method private _is_ready = source#is_ready
+    method fallible = source#fallible
+    method private can_generate_frame = source#is_ready
     method remaining = source#remaining
     method seek_source = source#seek_source
     method self_sync = source#self_sync
     method abort_track = source#abort_track
 
-    method private get_frame buf =
-      let offset = AFrame.position buf in
-      source#get buf;
-      let position = AFrame.position buf in
-      let buf = Content.Audio.get_data (Frame.get buf field) in
+    method private generate_frame =
+      let position = source#frame_audio_position in
+      let buf = Content.Audio.get_data (source#get_mutable_content field) in
       let width = width () in
       let width = (width +. 1.) /. 2. in
       let a =
@@ -108,14 +105,15 @@ class spatializer ~field ~width (source : source) =
         let w' = 1. -. width in
         w /. sqrt ((w *. w) +. (w' *. w'))
       in
-      for i = offset to position - 1 do
+      for i = 0 to position - 1 do
         let left = buf.(0).(i) in
         let right = buf.(1).(i) in
         let mid = (left +. right) /. 2. in
         let side = (left -. right) /. 2. in
         buf.(0).(i) <- ((1. -. a) *. mid) -. (a *. side);
         buf.(1).(i) <- ((1. -. a) *. mid) +. (a *. side)
-      done
+      done;
+      source#set_frame_data field Content.Audio.lift_data buf
   end
 
 let _ =
