@@ -1,7 +1,7 @@
 (*****************************************************************************
 
-  Liquidsoap, a programmable audio stream generator.
-  Copyright 2003-2023 Savonet team
+  Liquidsoap, a programmable stream generator.
+  Copyright 2003-2024 Savonet team
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -25,25 +25,23 @@ open Source
 class rms ~tau source =
   let samplerate = float (Lazy.force Frame.audio_rate) in
   object (self)
-    inherit operator [source] ~name:"rms" as super
-    method stype = source#stype
-    method private _is_ready = source#is_ready
+    inherit operator [source] ~name:"rms"
+    method fallible = source#fallible
+    method private can_generate_frame = source#is_ready
     method remaining = source#remaining
     method seek_source = source#seek_source
     method abort_track = source#abort_track
     method self_sync = source#self_sync
-    method! wake_up a = super#wake_up a
     val mutable rms = 0.
     method rms = sqrt rms
 
-    method private get_frame buf =
+    method private generate_frame =
       let chans = self#audio_channels in
       let a = 1. -. exp (-1. /. (tau () *. samplerate)) in
-      let offset = AFrame.position buf in
-      source#get buf;
-      let position = AFrame.position buf in
-      let buf = AFrame.pcm buf in
-      for i = offset to position - 1 do
+      let frame = source#get_frame in
+      let position = AFrame.position frame in
+      let buf = AFrame.pcm frame in
+      for i = 0 to position - 1 do
         let r = ref 0. in
         for c = 0 to chans - 1 do
           let x = buf.(c).(i) in
@@ -51,7 +49,8 @@ class rms ~tau source =
         done;
         let r = !r /. float chans in
         rms <- ((1. -. a) *. rms) +. (a *. r)
-      done
+      done;
+      frame
   end
 
 let _ =
