@@ -1,7 +1,7 @@
 (*****************************************************************************
 
-  Liquidsoap, a programmable audio stream generator.
-  Copyright 2003-2023 Savonet team
+  Liquidsoap, a programmable stream generator.
+  Copyright 2003-2024 Savonet team
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,63 +30,61 @@ type config = {
 
 class stereotool ~field ~handler source =
   object (self)
-    inherit Source.operator ~name:"stereotool" [source] as super
+    inherit Source.operator ~name:"stereotool" [source]
 
     val config =
-      lazy
-        ((* This is computed first to inject some audio data. *)
-         let latency =
-           Frame.seconds_of_audio
-             (Stereotool.latency
-                ~samplerate:(Lazy.force Frame.audio_rate)
-                ~feed_silence:true handler)
-         in
-         {
-           unlincensed_used_features =
-             Stereotool.unlincensed_used_features handler;
-           valid_license = Stereotool.valid_license handler;
-           latency;
-           api_version = Stereotool.api_version handler;
-           software_version = Stereotool.software_version handler;
-         })
+      Lazy.from_fun (fun () ->
+          (* This is computed first to inject some audio data. *)
+          let latency =
+            Frame.seconds_of_audio
+              (Stereotool.latency
+                 ~samplerate:(Lazy.force Frame.audio_rate)
+                 ~feed_silence:true handler)
+          in
+          {
+            unlincensed_used_features =
+              Stereotool.unlincensed_used_features handler;
+            valid_license = Stereotool.valid_license handler;
+            latency;
+            api_version = Stereotool.api_version handler;
+            software_version = Stereotool.software_version handler;
+          })
 
     method config = Lazy.force config
 
-    method! wake_up l =
-      super#wake_up l;
-      let {
-        unlincensed_used_features;
-        valid_license;
-        latency;
-        api_version;
-        software_version;
-      } =
-        self#config
-      in
-      self#log#important
-        "Stereotool initialized! Valid license: %b, latency: %.02fs, \
-         API/software version: %d/%d"
-        valid_license latency api_version software_version;
-      if not valid_license then self#log#severe "Using invalid license!";
-      match unlincensed_used_features with
-        | None -> ()
-        | Some s -> self#log#severe "Using unlicensed features: %s" s
+    initializer
+      self#on_wake_up (fun () ->
+          let {
+            unlincensed_used_features;
+            valid_license;
+            latency;
+            api_version;
+            software_version;
+          } =
+            self#config
+          in
+          self#log#important
+            "Stereotool initialized! Valid license: %b, latency: %.02fs, \
+             API/software version: %d/%d"
+            valid_license latency api_version software_version;
+          if not valid_license then self#log#severe "Using invalid license!";
+          match unlincensed_used_features with
+            | None -> ()
+            | Some s -> self#log#severe "Using unlicensed features: %s" s)
 
-    method stype = source#stype
+    method fallible = source#fallible
     method remaining = source#remaining
     method seek_source = source#seek_source
-    method private _is_ready = source#is_ready
+    method private can_generate_frame = source#is_ready
     method abort_track = source#abort_track
     method self_sync = source#self_sync
 
-    method private get_frame buf =
-      let offset = AFrame.position buf in
-      source#get buf;
-      let position = AFrame.position buf in
-      let b = Content.Audio.get_data (Frame.get buf field) in
+    method private generate_frame =
+      let b = Content.Audio.get_data (source#get_mutable_content field) in
       Stereotool.process
         ~samplerate:(Lazy.force Frame.audio_rate)
-        handler b offset (position - offset)
+        handler b 0 source#frame_audio_position;
+      source#set_frame_data field Content.Audio.lift_data b
   end
 
 let _ =
@@ -161,7 +159,7 @@ let _ =
           | "sublevel_pnr" -> `Sublevel_pnr
           | s ->
               let pos =
-                match load_type_val.Liquidsoap_lang.Value.pos with
+                match Liquidsoap_lang.Value.pos load_type_val with
                   | None -> Lang.pos p
                   | Some p -> [p]
               in
@@ -173,16 +171,24 @@ let _ =
       let preset = Lang.to_valued_option Lang.to_string preset_val in
       let handler =
         let library = Utils.check_readable ~pos:(Lang.pos p) library in
-        try Stereotool.init ?license_key ~filename:library ()
-        with Stereotool.Library_not_found ->
-          Runtime_error.raise ~pos:(Lang.pos p)
-            ~message:"Invalid stereotool library" "invalid"
+        try Stereotool.init ?license_key ~filename:library () with
+          | Stereotool.Library_not_found ->
+              Runtime_error.raise ~pos:(Lang.pos p)
+                ~message:"Invalid stereotool library" "invalid"
+          | Stereotool.Library_initialized f ->
+              Runtime_error.raise ~pos:(Lang.pos p)
+                ~message:
+                  (Printf.sprintf
+                     "Stereotool already initialized with a different library: \
+                      %s"
+                     (Lang_string.quote_string f))
+                "invalid"
       in
       (match preset with
         | None -> ()
         | Some filename ->
             let pos =
-              match preset_val.Liquidsoap_lang.Value.pos with
+              match Liquidsoap_lang.Value.pos preset_val with
                 | None -> Lang.pos p
                 | Some p -> [p]
             in
