@@ -23,17 +23,16 @@
 open Mm
 
 (** Create a buffer between two clocks.
-  *
-  * This creates an active operator in the inner clock (the action consists
-  * in filling the buffer) but it does not create or force in any
-  * way the clock that's going to animate it.
-  *
-  * We actually create two sources, to avoid the mess of having a same
-  * source belonging to one clock but being animated by another.
-  * This makes it possible to have the inner clock stop and shutdown
-  * the source that feeds the buffer, without disturbing the other clock
-  * in which the buffer-consumer will still behave OK (except obviously
-  * that the buffer will empty). *)
+
+    This creates an active operator in the inner clock (the action consists in
+    filling the buffer) but it does not create or force in any way the clock
+    that's going to animate it.
+
+    We actually create two sources, to avoid the mess of having a same source
+    belonging to one clock but being animated by another. This makes it possible
+    to have the inner clock stop and shutdown the source that feeds the buffer,
+    without disturbing the other clock in which the buffer-consumer will still
+    behave OK (except obviously that the buffer will empty). *)
 module Buffer = struct
   (* The kind of value shared by a producer and a consumer. *)
   type control = {
@@ -86,6 +85,7 @@ module Buffer = struct
     ~max_buffer source_val c =
     let prebuf = Frame.main_of_seconds pre_buffer in
     let maxbuf = Frame.main_of_seconds max_buffer in
+    let source = Lang.to_source source_val in
     object
       inherit
         Output.output
@@ -95,6 +95,7 @@ module Buffer = struct
       method! reset = ()
       method start = ()
       method stop = ()
+      method self_sync = source#self_sync
       val source = Lang.to_source source_val
 
       method send_frame frame =
@@ -362,6 +363,7 @@ module AdaptativeBuffer = struct
   class consumer ~autostart ~infallible ~on_start ~on_stop ~pre_buffer ~reset
     source_val c =
     let prebuf = Frame.audio_of_seconds pre_buffer in
+    let source = Lang.to_source source_val in
     object (self)
       inherit
         Output.output
@@ -372,6 +374,7 @@ module AdaptativeBuffer = struct
       method! reset = ()
       method start = ()
       method stop = ()
+      method self_sync = source#self_sync
       val source = Lang.to_source source_val
 
       method send_frame frame =
