@@ -61,12 +61,12 @@ module M = Icecast_utils.Icecast_v (Icecast)
 open M
 
 (* Max total length for ICY metadata is 255*16
- * Format is: "StreamTitle='%s';StreamUrl='%s'"
- * "StreamTitle='';"; is 15 chars long, "StreamUrl='';"
- * is 13 chars long, leaving 4052 chars remaining.
- * Splitting those in:
- * * max title length = 3852
- * * max url length = 200 *)
+   Format is: "StreamTitle='%s';StreamUrl='%s'"
+   "StreamTitle='';"; is 15 chars long, "StreamUrl='';"
+   is 13 chars long, leaving 4052 chars remaining.
+   Splitting those in:
+     max title length = 3852
+     max url length = 200 *)
 let max_title = 3852
 let max_url = 200
 
@@ -297,8 +297,8 @@ let client_task c =
     ();
   Duppy.Monad.catch (client_task c) (fun _ -> Duppy.Monad.raise ())
 
-(** Sending encoded data to a shout-compatible server.
-    * It directly takes the Lang param list and extracts stuff from it. *)
+(** Sending encoded data to a shout-compatible server. It directly takes the
+    Lang param list and extracts stuff from it. *)
 class output p =
   let pos = Lang.pos p in
   let e f v = f (List.assoc v p) in
@@ -346,7 +346,8 @@ class output p =
            (List.assoc "buffer" p, "Maximum buffering inferior to burst length"))
     else ()
   in
-  let source = Lang.assoc "" 2 p in
+  let source_val = Lang.assoc "" 2 p in
+  let source = Lang.to_source source_val in
   let mount = s "mount" in
   let uri =
     match mount.[0] with '/' -> mount | _ -> Printf.sprintf "%c%s" '/' mount
@@ -419,7 +420,7 @@ class output p =
     inherit
       [Strings.t] Output.encoded
         ~output_kind:"output.harbor" ~infallible ~register_telnet ~autostart
-          ~export_cover_metadata:false ~on_start ~on_stop ~name:mount source
+          ~export_cover_metadata:false ~on_start ~on_stop ~name:mount source_val
 
     val mutable dump = None
     val mutable encoder = None
@@ -431,6 +432,7 @@ class output p =
     val burst_data = Strings.Mutable.empty ()
     val metadata = { metadata = None; metadata_m = Mutex.create () }
     method encode frame = (Option.get encoder).Encoder.encode frame
+    method self_sync = source#self_sync
 
     method insert_metadata m =
       let m = Frame.Metadata.Export.to_metadata m in
