@@ -318,7 +318,8 @@ type metadata =
 
 let pending_metadata = function `Todo _ -> true | _ -> false
 
-(** A stream in the HLS (which typically contains many, with different qualities). *)
+(** A stream in the HLS (which typically contains many, with different
+    qualities). *)
 type stream = {
   name : string;
   format : Encoder.format;
@@ -619,7 +620,8 @@ class hls_output p =
         then 7
         else 3)
   in
-  let source = Lang.assoc "" 3 p in
+  let source_val = Lang.assoc "" 3 p in
+  let source = Lang.to_source source_val in
   let main_playlist_filename = Lang.to_string (List.assoc "playlist" p) in
   let main_playlist_extra_tags =
     List.map
@@ -640,7 +642,7 @@ class hls_output p =
       [(int * Strings.t option * Strings.t) list] Output.encoded
         ~infallible ~register_telnet ~on_start ~on_stop ~autostart
           ~export_cover_metadata:false ~output_kind:"output.file"
-          ~name:main_playlist_filename source
+          ~name:main_playlist_filename source_val
 
     (** Available segments *)
     val mutable segments = List.map (fun { name } -> (name, ref [])) streams
@@ -649,6 +651,7 @@ class hls_output p =
     method streams = streams
     val mutable current_position = (0, 0)
     val mutable state : hls_state = `Idle
+    method self_sync = source#self_sync
 
     method private toggle_state event =
       match (event, state) with
@@ -1079,21 +1082,22 @@ class hls_output p =
       if segment.len + len > segment_main_duration then
         ( true,
           Printf.sprintf
-            "Terminating current segment on stream %s to make expected length"
-            s.name,
+            "Terminating current segment %d on stream %s to make expected \
+             length"
+            segment.id s.name,
           true )
       else if s.id3_enabled && pending_metadata s.metadata then
         ( true,
           Printf.sprintf
-            "Terminating current segment on stream %s to insert new metadata"
-            s.name,
+            "Terminating current segment %d on stream %s to insert new metadata"
+            segment.id s.name,
           false )
       else if Atomic.get s.pending_extra_tags <> [] then
         ( true,
           Printf.sprintf
-            "Terminating current segment on stream %s to insert pending extra \
-             tags"
-            s.name,
+            "Terminating current segment %d on stream %s to insert pending \
+             extra tags"
+            segment.id s.name,
           false )
       else (false, "", false)
 
