@@ -24,7 +24,7 @@ open Mm
 
 exception Unavailable
 
-module Queue = Liquidsoap_lang.Queues.Queue
+module Queue = Queues.Queue
 
 type streaming_state =
   [ `Pending | `Unavailable | `Ready of unit -> unit | `Done of Frame.t ]
@@ -76,7 +76,7 @@ let finalise s =
       (Printf.sprintf "Error when leaving output %s: %s!" s#id
          (Printexc.to_string e))
 
-class virtual operator ?(stack = []) ?clock ?(name = "src") sources =
+class virtual operator ?(stack = []) ?clock ~name sources =
   let frame_type = Type.var () in
   let clock = match clock with Some c -> c | None -> Clock.create ~stack () in
   object (self)
@@ -106,29 +106,24 @@ class virtual operator ?(stack = []) ?clock ?(name = "src") sources =
     val mutable log = source_log
     method private create_log = log <- Log.make [self#id]
     method log = log
-    val mutable id = ""
-    val mutable definitive_id = false
-    val mutable name = name
-    method set_name n = name <- n
-    initializer id <- Lang_string.generate_id name
+    val mutable id = Lang_string.generate_id name
     method id = id
 
-    method set_id ?(definitive = true) s =
+    method set_id ?(force = true) s =
       let s =
         Re.Pcre.substitute
           ~rex:(Re.Pcre.regexp "[ \t\n.]")
           ~subst:(fun _ -> "_")
           s
       in
-      if not definitive_id then (
+      if force && s <> self#id then (
         id <- Lang_string.generate_id s;
-        definitive_id <- definitive);
 
-      (* Sometimes the ID is changed during initialization, in order to make it
+        (* Sometimes the ID is changed during initialization, in order to make it
          equal to the server name, which is only registered at initialization
          time in order to avoid bloating from unused sources. If the ID
          changes, and [log] has already been initialized, reset it. *)
-      if log != source_log then self#create_log
+        if log != source_log then self#create_log)
 
     val mutex = Mutex.create ()
 
@@ -159,10 +154,18 @@ class virtual operator ?(stack = []) ?clock ?(name = "src") sources =
     val mutable sources : operator list = sources
 
     method virtual self_sync : Clock.self_sync
+    val mutable self_sync_source = None
+
+    method private self_sync_source =
+      match self_sync_source with
+        | None ->
+            let s = SourceSync.make (self :> < id : string >) in
+            self_sync_source <- Some s;
+            s
+        | Some s -> s
 
     method source_sync self_sync =
-      if self_sync then Some (SourceSync.make (self :> < id : string >))
-      else None
+      if self_sync then Some self#self_sync_source else None
 
     (* Type describing the contents of the frame: this should be a record
        whose fields (audio, video, etc.) indicate the kind of contents we
@@ -197,20 +200,50 @@ class virtual operator ?(stack = []) ?clock ?(name = "src") sources =
             ctype <- Some ct;
             ct
 
+    val mutable audio_channels = -1
+
     method private audio_channels =
-      match Frame.Fields.find_opt Frame.Fields.audio self#content_type with
-        | Some c when Content.Audio.is_format c ->
-            Content.Audio.channels_of_format c
-        | Some c when Content_pcm_s16.is_format c ->
-            Content_pcm_s16.channels_of_format c
-        | Some c when Content_pcm_f32.is_format c ->
-            Content_pcm_f32.channels_of_format c
-        | _ -> raise Content.Invalid
+      match audio_channels with
+        | -1 ->
+            let c =
+              match
+                Frame.Fields.find_opt Frame.Fields.audio self#content_type
+              with
+                | Some c when Content.Audio.is_format c ->
+                    Content.Audio.channels_of_format c
+                | Some c when Content_pcm_s16.is_format c ->
+                    Content_pcm_s16.channels_of_format c
+                | Some c when Content_pcm_f32.is_format c ->
+                    Content_pcm_f32.channels_of_format c
+                | _ -> raise Content.Invalid
+            in
+            audio_channels <- c;
+            c
+        | c -> c
+
+    val mutable samplerate = -1.
+
+    method private samplerate =
+      match samplerate with
+        | -1. ->
+            let s = float_of_int (Lazy.force Frame.audio_rate) in
+            samplerate <- s;
+            s
+        | s -> s
+
+    val mutable video_dimensions = None
 
     method private video_dimensions =
-      Content.Video.dimensions_of_format
-        (Option.get
-           (Frame.Fields.find_opt Frame.Fields.video self#content_type))
+      match video_dimensions with
+        | None ->
+            let dim =
+              Content.Video.dimensions_of_format
+                (Option.get
+                   (Frame.Fields.find_opt Frame.Fields.video self#content_type))
+            in
+            video_dimensions <- Some dim;
+            dim
+        | Some dim -> dim
 
     val mutable on_wake_up = []
     method on_wake_up fn = on_wake_up <- fn :: on_wake_up
@@ -233,7 +266,8 @@ class virtual operator ?(stack = []) ?clock ?(name = "src") sources =
           self#content_type_computation_allowed;
           if log == source_log then self#create_log;
           source_log#info
-            "Source %s gets up with content type: %s and frame type: %s." id
+            "Source %s gets up with content type: %s and frame type: %s."
+            self#id
             (Frame.string_of_content_type self#content_type)
             (Type.to_string self#frame_type);
           self#log#debug "Clock is %s." (Clock.id self#clock);
@@ -254,7 +288,7 @@ class virtual operator ?(stack = []) ?clock ?(name = "src") sources =
 
     method force_sleep =
       if Atomic.compare_and_set is_up `True `False then (
-        source_log#info "Source %s gets down." id;
+        source_log#info "Source %s gets down." self#id;
         List.iter (fun fn -> fn ()) on_sleep)
 
     method sleep =
@@ -331,22 +365,22 @@ class virtual operator ?(stack = []) ?clock ?(name = "src") sources =
             if cache_pos > 0 || can_generate_frame then
               Atomic.set streaming_state
                 (`Ready
-                  (fun () ->
-                    let buf =
-                      if can_generate_frame && cache_pos < size then
-                        Frame.append cache self#instrumented_generate_frame
-                      else cache
-                    in
-                    let buf_pos = Frame.position buf in
-                    let buf =
-                      if size < buf_pos then (
-                        _cache <- Some (Frame.after buf size);
-                        Frame.slice buf size)
-                      else (
-                        _cache <- None;
-                        buf)
-                    in
-                    Atomic.set streaming_state (`Done buf)))
+                   (fun () ->
+                     let buf =
+                       if can_generate_frame && cache_pos < size then
+                         Frame.append cache self#instrumented_generate_frame
+                       else cache
+                     in
+                     let buf_pos = Frame.position buf in
+                     let buf =
+                       if size < buf_pos then (
+                         _cache <- Some (Frame.after buf size);
+                         Frame.slice buf size)
+                       else (
+                         _cache <- None;
+                         buf)
+                     in
+                     Atomic.set streaming_state (`Done buf)))
             else Atomic.set streaming_state `Unavailable;
             Clock.after_tick self#clock (fun () -> self#after_streaming_cycle)
         | _ -> ()
@@ -386,12 +420,12 @@ class virtual operator ?(stack = []) ?clock ?(name = "src") sources =
     method get_mutable_frame field =
       Frame.set self#get_frame field (self#get_mutable_content field)
 
-    method set_frame_data
-        : 'a.
-          Frame.field ->
-          (?offset:int -> ?length:int -> 'a -> Content.data) ->
-          'a ->
-          Frame.t =
+    method set_frame_data :
+        'a.
+        Frame.field ->
+        (?offset:int -> ?length:int -> 'a -> Content.data) ->
+        'a ->
+        Frame.t =
       fun field lift data -> Frame.set_data self#get_frame field lift data
 
     method private split_frame frame =
@@ -572,9 +606,9 @@ class virtual operator ?(stack = []) ?clock ?(name = "src") sources =
   end
 
 (** Entry-point sources, which need to actively perform some task. *)
-and virtual active_operator ?stack ?clock ?name sources =
+and virtual active_operator ?stack ?clock ~name sources =
   object (self)
-    inherit operator ?stack ?clock ?name sources
+    inherit operator ?stack ?clock ~name sources
     method! source_type : source_type = `Active (self :> active)
 
     (** Do whatever needed when the latency gets too big and is reset. *)
@@ -583,14 +617,14 @@ and virtual active_operator ?stack ?clock ?name sources =
 
 (** Shortcuts for defining sources with no children *)
 
-and virtual source ?stack ?clock ?name () =
+and virtual source ?stack ?clock ~name () =
   object
-    inherit operator ?stack ?clock ?name []
+    inherit operator ?stack ?clock ~name []
   end
 
-class virtual active_source ?stack ?clock ?name () =
+class virtual active_source ?stack ?clock ~name () =
   object
-    inherit active_operator ?stack ?clock ?name []
+    inherit active_operator ?stack ?clock ~name []
   end
 
 (* Reselect type. This drives the choice of next source.
@@ -609,6 +643,8 @@ class virtual generate_from_multiple_sources ~merge ~track_sensitive () =
     method virtual private execute_on_track : Frame.t -> unit
     method virtual private set_last_metadata : Frame.t -> unit
     method virtual log : Log.t
+    method virtual id : string
+    val mutable ready_source = None
 
     method private can_generate_frame =
       match
@@ -616,8 +652,12 @@ class virtual generate_from_multiple_sources ~merge ~track_sensitive () =
           ~reselect:(if track_sensitive () then `Ok else `Force)
           ()
       with
-        | Some s -> s#is_ready
-        | None -> false
+        | Some s when s#is_ready ->
+            ready_source <- Some s;
+            true
+        | _ ->
+            ready_source <- None;
+            false
 
     val mutable current_source = None
 
@@ -645,7 +685,7 @@ class virtual generate_from_multiple_sources ~merge ~track_sensitive () =
             | buf, _ -> buf)
 
     method private generate_frame =
-      let s = Option.get (self#get_source ~reselect:`Ok ()) in
+      let s = Option.get ready_source in
       assert s#is_ready;
       let buf = self#continue_frame s in
       let size = Lazy.force Frame.size in
