@@ -1,7 +1,7 @@
 (*****************************************************************************
 
-  Liquidsoap, a programmable audio stream generator.
-  Copyright 2003-2023 Savonet team
+  Liquidsoap, a programmable stream generator.
+  Copyright 2003-2024 Savonet team
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -25,21 +25,9 @@ open Frame
 type t = Frame.t
 
 let mot = midi_of_main
-let tom = main_of_midi
 let size () = mot (Lazy.force Frame.size)
-let position t = mot (position t)
 
 let content ?(field = Frame.Fields.midi) b =
   try Frame.get b field with Not_found -> raise Content.Invalid
 
 let midi ?field b = Content.Midi.get_data (content ?field b)
-let add_break t i = add_break t (tom i)
-let is_partial = is_partial
-
-type metadata = (string, string) Hashtbl.t
-
-let set_metadata t i m = set_metadata t (tom i) m
-let get_metadata t i = get_metadata t (tom i)
-
-let get_all_metadata t =
-  List.map (fun (x, y) -> (mot x, y)) (get_all_metadata t)
