@@ -1,7 +1,7 @@
 (*****************************************************************************
 
-  Liquidsoap, a programmable audio stream generator.
-  Copyright 2003-2023 Savonet team
+  Liquidsoap, a programmable stream generator.
+  Copyright 2003-2024 Savonet team
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -146,7 +146,7 @@ let ffmpeg_mime_of_format = function
 
 module Icecast_v (M : Icecast_t) = struct
   type encoder_data = {
-    factory : string -> Export_metadata.metadata -> Encoder.encoder;
+    factory : string -> Frame.Metadata.Export.t -> Encoder.encoder;
     format : M.content;
     info : Encoder.encoder -> M.info;
   }
@@ -171,7 +171,7 @@ module Icecast_v (M : Icecast_t) = struct
             | Some v -> ffmpeg_mime_of_format v)
     | Encoder.FdkAacEnc _ -> Some aac
     | Encoder.External _ -> None
-    | Encoder.GStreamer _ -> None
+    | Encoder.NDI _ -> None
     | Encoder.Flac _ -> Some flac
     | Encoder.WAV _ -> Some wav
     | Encoder.AVI _ -> Some avi
@@ -180,9 +180,9 @@ module Icecast_v (M : Icecast_t) = struct
   let encoder_overrides = function
     | Encoder.Ffmpeg { Ffmpeg_format.format = Some "mp3"; opts } as e ->
         if not (Hashtbl.mem opts "id3v2_version") then
-          Hashtbl.add opts "id3v2_version" (`Int 0);
+          Hashtbl.replace opts "id3v2_version" (`Int 0);
         if not (Hashtbl.mem opts "write_xing") then
-          Hashtbl.add opts "write_xing" (`Int 0);
+          Hashtbl.replace opts "write_xing" (`Int 0);
         e
     | e -> e
 
@@ -207,5 +207,5 @@ module Icecast_v (M : Icecast_t) = struct
                    ( Lang.assoc "" 1 p,
                      "No format (mime) found, please specify one." )))
     in
-    { factory = encoder_factory ~pos:v.Value.pos; format; info }
+    { factory = encoder_factory ~pos:(Value.pos v); format; info }
 end
