@@ -1,7 +1,7 @@
 (*****************************************************************************
 
-  Liquidsoap, a programmable audio stream generator.
-  Copyright 2003-2023 Savonet team
+  Liquidsoap, a programmable stream generator.
+  Copyright 2003-2024 Savonet team
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -26,16 +26,17 @@ open Source
 class midimeter source =
   object
     inherit operator ~name:"midi.inspect" [source]
-    method stype = source#stype
-    method private _is_ready = source#is_ready
+    method fallible = source#fallible
+    method private can_generate_frame = source#is_ready
     method remaining = source#remaining
     method abort_track = source#abort_track
     method self_sync = source#self_sync
     method seek_source = source#seek_source
 
-    method get_frame buf =
-      source#get buf;
-      let m = MFrame.midi buf in
+    method generate_frame =
+      let m =
+        Content.Midi.get_data (source#get_mutable_content Frame.Fields.midi)
+      in
       (* Printf.printf "len: %d\n%!" (List.length (MIDI.data m.(0))); *)
       for c = 0 to Array.length m - 1 do
         List.iter
@@ -52,7 +53,8 @@ class midimeter source =
             in
             Printf.printf "%d: %s.\n%!" c s)
           (MIDI.data m.(c))
-      done
+      done;
+      source#set_frame_data Frame.Fields.midi Content.Midi.lift_data m
   end
 
 let _ =
