@@ -1,7 +1,7 @@
 (*****************************************************************************
 
-  Liquidsoap, a programmable audio stream generator.
-  Copyright 2003-2023 Savonet team
+  Liquidsoap, a programmable stream generator.
+  Copyright 2003-2024 Savonet team
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -33,6 +33,11 @@ let default_typing_environment () = Env.bindings !type_environment
    adding a field b to a). It is used only for [has_builtins] and
    [get_builtins]. *)
 let flat_enviroment : (string * (Type.scheme * Value.t)) list ref = ref []
+
+let clear_toplevel_environments () =
+  type_environment := Env.empty;
+  flat_enviroment := []
+
 let has_builtin name = List.mem_assoc name !flat_enviroment
 let get_builtin name = List.assoc_opt name !flat_enviroment
 
@@ -73,7 +78,7 @@ let add_builtin ?(override = false) ?(register = true) ?doc name ((g, t), v) =
                         },
                         t0 ))
               in
-              ((g0, t), Value.{ v0 with methods = Methods.add l v v0.methods })
+              ((g0, t), Value.map_methods v0 (Methods.add l v))
           | l :: ll ->
               let (vg, vt), v = aux (Type.invoke t0 l) (Value.invoke v0 l) ll in
               let t =
@@ -89,7 +94,7 @@ let add_builtin ?(override = false) ?(register = true) ?doc name ((g, t), v) =
                         },
                         t0 ))
               in
-              ((g0, t), Value.{ v0 with methods = Methods.add l v v0.methods })
+              ((g0, t), Value.map_methods v0 (Methods.add l v))
           | [] -> ((g, t), v)
         in
         let (g, t), v = aux (g0, t0) v0 ll in
@@ -120,8 +125,4 @@ let add_module name =
           ignore (Value.invoke e l);
           failwith ("Module " ^ String.concat "." name ^ " already exists")
         with _ -> ()));
-  add_builtin ~register:false name
-    ( ([], Type.make Type.unit),
-      Value.
-        { pos = None; value = unit; methods = Methods.empty; id = Value.id () }
-    )
+  add_builtin ~register:false name (([], Type.make Type.unit), Value.(make unit))
