@@ -1,7 +1,5 @@
 (* Language essentials *)
 
-val regexp : (?flags:Regexp.flag list -> string -> Regexp.regexp) ref
-
 type log =
   < f : 'a. int -> ('a, unit, string, unit) format4 -> 'a
   ; critical : 'a. ('a, unit, string, unit) format4 -> 'a
@@ -15,28 +13,32 @@ val log : string list -> log
 val liq_libs_dir : (unit -> string) ref
 val log_path : string option ref
 
+type dirtype = [ `User | `System ]
+
+val cache_maintenance : (dirtype -> unit) ref
+
 (* Media-specific dependencies. *)
 
 val eval_check :
-  (env:(string * Value.t lazy_t) list -> tm:Term.term -> Value.t -> unit) ref
+  (env:(string * Value.t) list -> tm:Term.t -> Value.t -> unit) ref
 
 type encoder_params =
-  (string * [ `Value of Value.t | `Encoder of encoder ]) list
+  [ `Anonymous of string | `Encoder of encoder | `Labelled of string * Value.t ]
+  list
 
 and encoder = string * encoder_params
 
-val make_encoder : (pos:Pos.Option.t -> Term.t -> encoder -> Value.t) ref
+val make_encoder : (pos:Pos.Option.t -> encoder -> Value.t) ref
 val type_of_encoder : (pos:Pos.Option.t -> Term.encoder -> Type.t) ref
 val has_encoder : (Value.t -> bool) ref
-val collect_after : ((unit -> Value.t) -> Value.t) ref
 
 val mk_source_ty :
-  (pos:Pos.t ->
-  extensible:bool ->
+  (?pos:Term_base.parsed_pos ->
   string ->
-  (string * (string * (string * string) list)) list ->
+  Parsed_term.source_annotation ->
   Type.t)
   ref
 
+val mk_clock_ty : (?pos:Term_base.parsed_pos -> unit -> Type.t) ref
 val source_methods_t : (unit -> Type.t) ref
 val getpwnam : (string -> Unix.passwd_entry) ref
