@@ -60,7 +60,11 @@ val load_libs : ?stdlib:string -> unit -> unit
 (* Wrapper for format language errors. Re-raises [Error]
    after printing language errors. *)
 val throw :
-  ?formatter:Format.formatter -> ?lexbuf:Sedlexing.lexbuf -> unit -> exn -> unit
+  ?formatter:Format.formatter ->
+  lexbuf:Sedlexing.lexbuf option ->
+  unit ->
+  exn ->
+  unit
 
 val program :
   (unit -> Parser.token * Lexing.position * Lexing.position) -> Parsed_term.t
@@ -75,7 +79,7 @@ val error_header : formatter:Format.formatter -> int -> Pos.Option.t -> unit
 
 (** Report language errors. *)
 val report :
-  ?lexbuf:Sedlexing.lexbuf ->
   ?default:(unit -> 'a) ->
+  lexbuf:Sedlexing.lexbuf option ->
   (throw:(exn -> unit) -> unit -> 'a) ->
   'a
