@@ -23,7 +23,7 @@
 module Runtime = Liquidsoap_lang.Runtime
 module Environment = Liquidsoap_lang.Environment
 module Profiler = Liquidsoap_lang.Profiler
-module Queue = Liquidsoap_lang.Queues.Queue
+module Queue = Queues.Queue
 
 let usage =
   {|Usage : liquidsoap [OPTION, SCRIPT or EXPR]...
@@ -574,25 +574,6 @@ To change it, add the following to your script:
   if Dtools.Init.conf_daemon#get && Dtools.Init.conf_daemon_pidfile#get then
     check_dir Dtools.Init.conf_daemon_pidfile_path "PID"
 
-(** A function to reopen a file descriptor
-    * Thanks to Xavier Leroy!
-    * Ref: http://caml.inria.fr/pub/ml-archives/caml-list/2000/01/
-    *      a7e3bbdfaab33603320d75dbdcd40c37.en.html
-    *)
-let reopen_out outchan filename =
-  flush outchan;
-  let fd1 = Unix.descr_of_out_channel outchan in
-  let fd2 = Unix.openfile filename [Unix.O_WRONLY] 0o666 in
-  Unix.dup2 fd2 fd1;
-  Unix.close fd2
-
-(** The same for inchan *)
-let reopen_in inchan filename =
-  let fd1 = Unix.descr_of_in_channel inchan in
-  let fd2 = Unix.openfile filename [Unix.O_RDONLY] 0o666 in
-  Unix.dup2 fd2 fd1;
-  Unix.close fd2
-
 let () =
   Dtools.Init.conf_daemon#on_change (fun v ->
       if v then
@@ -643,9 +624,9 @@ let daemonize () =
     close_out f
   end;
   (* Reopen usual file descriptor *)
-  reopen_in stdin "/dev/null";
-  reopen_out stdout "/dev/null";
-  reopen_out stderr "/dev/null"
+  Utils.reopen_in stdin "/dev/null";
+  Utils.reopen_out stdout "/dev/null";
+  Utils.reopen_out stderr "/dev/null"
 
 let () =
   Lifecycle.before_start ~name:"main application before start" (fun () ->
