@@ -35,6 +35,13 @@ let () =
   ./jingles
   ./playlist
   ./huge_playlist
+  ./replaygain_track_gain.mp3
+  ./r128_track_gain.mp3
+  ./replaygain_r128_track_gain.mp3
+  ./replaygain_track_gain.opus
+  ./r128_track_gain.opus
+  ./replaygain_r128_track_gain.opus
+  ./without_replaygain_track_gain.mp3
   ./crossfade-plot.old.txt
   ./crossfade-plot.new.txt
   ../../src/bin/liquidsoap.exe
